@@ -1,13 +1,15 @@
 # -*- coding: utf-8 -*-
-"""
-This module provides a context manager for setting the Unix terminals to raw mode.
-"""
+import os
 import sys
 from contextlib import contextmanager
 
 from click._compat import isatty
 
-WIN = sys.platform.startswith('win')
+WIN = sys.platform.startswith("win")
+CI = "CI" in os.environ
+
+env = os.environ
+
 
 @contextmanager
 def raw_mode():
@@ -21,15 +23,16 @@ def raw_mode():
         with raw_mode():
             do_some_stuff()
     """
-    if WIN:
+    if WIN or CI:
         # No implementation for windows yet.
         yield  # needed for the empty context manager to work
     else:
         #  imports are placed here because this will fail under Windows
         import tty
         import termios
+
         if not isatty(sys.stdin):
-            f = open('/dev/tty')
+            f = open("/dev/tty")
             fd = f.fileno()
         else:
             fd = sys.stdin.fileno()
@@ -43,7 +46,7 @@ def raw_mode():
             yield
         finally:
             # this block sets the terminal to sane mode again,
-            # also in case an exception occured in the context manager
+            # also in case an exception occurred in the context manager
             try:
                 termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
                 # sys.stdout.flush()  # not needed I think.
@@ -51,3 +54,7 @@ def raw_mode():
                     f.close()
             except termios.error:
                 pass
+
+
+def get_default_shell():
+    return env.get("DOITLIVE_INTERPRETER") or env.get("SHELL") or "/bin/bash"
